@@ -131,7 +131,7 @@ namespace Oxygen
         protected:
 
         //! dirty
-        virtual void setDirty( void ) const;
+        void setDirty( void ) const ;
 
         private:
 
